==> v4.1.3.zip: groupfolders/l10n/ru.js <==
OC.L10N.register(
    "groupfolders",
    {
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation can not be undone" : "Действительно удалить «{folderName}» и все вложенные файлы? Эта операция необратима.",
    "Delete \"{folderName}\"?" : "Удалить «{folderName}\"»?",
    "Folder name" : "Имя папки",
    "Groups" : "Группы",
    "Quota" : "Квота",
    "Advanced Permissions" : "Расширенные разрешения",
    "Group folders" : "Каталоги групп",
    "Admin configured folders shared by everyone in a group" : "Папки, общие для всех в группе, настроенные администратором",
    "Admin configured folders shared by everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder.\n\nNote: encrypting the contents of group folders is currently not supported." : "Папки, общие для всех в группе, настроенные администратором.\n\nПапки можно настроить из * Папок групп * в настройках администратора.\n\nПосле создания папки, администратор может предоставить доступ к ней одной или нескольким группам, управлять разрешениями на запись и совместное использование и назначить квоту для этой папки.\n\nПримечание: шифрование содержимого папок групп в настоящее время не поддерживается.",
    "Denied" : "Запрещено",
    "Allowed" : "Разрешено",
    "Denied (Inherited permission)" : "Запрещено (унаследовано)",
    "Allowed (Inherited permission)" : "Разрешено (унаследовано)",
    "Groupfolder" : "Групповая папка",
    "Read" : "Чтение",
    "Write" : "Запись",
    "Create" : "Создание",
    "Delete" : "Удаление",
    "Share" : "Общий доступ",
    "You" : "Вы",
    "(Group)" : "(Группа)",
    "Remove access rule" : "Удалить правило доступа",
    "Add advanced permission rule" : "Добавить расширенное правило доступа"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> v6.0.0.zip: groupfolders/l10n/ru.js <==
OC.L10N.register(
    "groupfolders",
    {
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation can not be undone" : "Действительно удалить «{folderName}» и все вложенные файлы? Эта операция необратима.",
    "Delete \"{folderName}\"?" : "Удалить «{folderName}\"»?",
    "Folder name" : "Имя папки",
    "Groups" : "Группы",
    "Quota" : "Квота",
    "Advanced Permissions" : "Расширенные права доступа",
    "Group folders" : "Каталоги групп",
    "Admin configured folders shared by everyone in a group" : "Папки, общие для всех в группе, настроенные администратором",
    "Admin configured folders shared by everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder.\n\nNote: encrypting the contents of group folders is currently not supported." : "Папки, общие для всех в группе, настроенные администратором.\n\nПапки можно настроить из * Папок групп * в настройках администратора.\n\nПосле создания папки, администратор может предоставить доступ к ней одной или нескольким группам, управлять разрешениями на запись и совместное использование и назначить квоту для этой папки.\n\nПримечание: шифрование содержимого папок групп в настоящее время не поддерживается.",
    "Denied" : "Запрещено",
    "Allowed" : "Разрешено",
    "Denied (Inherited permission)" : "Запрещено (унаследовано)",
    "Allowed (Inherited permission)" : "Разрешено (унаследовано)",
    "Inherit permission" : "Наследование разрешений",
    "Deny" : "Запретить",
    "Allow" : "Разрешить",
    "Groupfolder" : "Групповая папка",
    "Read" : "Чтение",
    "Write" : "Запись",
    "Create" : "Создание",
    "Delete" : "Удаление",
    "Share" : "Публикация",
    "You" : "Вы",
    "(Group)" : "(Группа)",
    "Remove access rule" : "Удалить правило доступа",
    "Add advanced permission rule" : "Добавить расширенное правило доступа",
    "Select a user or group" : "Выберите пользователя или группу"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
